| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Network.Unexceptional.MutableBytes
Documentation
Receive bytes from a socket. Receives at most N bytes, where N is the size of the buffer. Returns the number of bytes that were actually received.
| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Network.Unexceptional.MutableBytes
Receive bytes from a socket. Receives at most N bytes, where N is the size of the buffer. Returns the number of bytes that were actually received.